//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[HoraOptions](index.md)/[hasKiriageMangan](has-kiriage-mangan.md)

# hasKiriageMangan

[common]\
val [hasKiriageMangan](has-kiriage-mangan.md): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)

是否有切上满贯
